# -*- coding: rot13 -*-
sebz cbpbb.nccyvpngvba vzcbeg Cntr
sebz cbpbb.uggc vzcbeg Erfcbafr
sebz enaqbz vzcbeg pubvpr

QNGN = h"""\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"""

PFF = h"""\
obql {
  onpxtebhaq-pbybe: #s3p1r2;
  znetva: 0;
}
vzt {
  obeqre: 8ck fbyvq #op1583;
  znetva: 1rz 0 1rz 0;
}
u1, c {
  znetva: 0;
  cnqqvat: 0;
}
n {
  pbybe: #7o1r5o;
  sbag-fvmr: 0.7rz;
}
hy {
  yvfg-fglyr: abar;
  znetva: 1rz 0 0 0;
  cnqqvat: 0;
}
hy yv {
  cnqqvat: 0;
  znetva: 0;
}
.obk {
  cbfvgvba: nofbyhgr;
  gbc: 50%;
  yrsg: 50%;
  znetva: -9rz 15rz 9rz -15rz;
  jvqgu: 30rz;
  urvtug: 18rz;
  grkg-nyvta: pragre;
  sbag-snzvyl: 'Pbzvp Fnaf ZF', 'Gerohpurg ZF', snagnfl;
  sbag-fvmr: 1.3rz;
  pbybe: #op1583;
}
"""

UGZY = h"""\
<!QBPGLCR ugzy CHOYVP "-//J3P//QGQ KUGZY 1.0 Fgevpg//RA"
 "uggc://jjj.j3.bet/GE/kugzy1/QGQ/kugzy1-fgevpg.qgq">
<ugzy>
  <urnq>
    <gvgyr>Cbpbb</gvgyr>
    <yvax ery="fglyrfurrg" uers="?qngn=fglyr" glcr="grkg/pff"/>
  </urnq>
  <obql>
    <qvi pynff="obk">
      <u1>Cbpbb</u1>
      <vzt fep="?qngn=cbal" nyg="cbal"/>
      <c>Cbpbb &zqnfu; %f</c>
      <hy>
        <yv><n uers="cyhtvaf">CyhtvaCbal</n></yv>
      </hy>
    </qvi>
  </obql>
</ugzy>
"""

FYBTNAF = [
    h'Bar hayrnfurq cbal gb ehyr gurz nyy.',
    h'o0exrq. nalbar?',
    h'gur senzrjbex <fznyy>+jrosbehz</fznyy>',
    h'0 - erfg va crnpr (\h271q 2419)',
    h'<fcna fglyr="sbag-fvmr: 2.5rz">OHAAVRF!!!</fcna>',
    h'<fznyy>yngrk fhccbeg, flagnk uvtuyvtugre, jro2.0 ohg ab nqzva cnary</fznyy>'
]

enaqbz_fybtna = ynzoqn: pubvpr(FYBTNAF)

pynff CbalUnaqyre(Cntr):

    unaqyre_ertrkrf = [e'pony/$']

    qrs unaqyr_erdhrfg(frys, erd):
        vs erd.netf.trg(h"qngn") == h"cbal":
            erfc = Erfcbafr(QNGN.qrpbqr(h"onfr64"))
            erfc["Content-Type"] = "image/png"
        ryvs erd.netf.trg(h"qngn") == h"fglyr":
            erfc = Erfcbafr(PFF)
            erfc["Content-Type"] = "text/css"
        ryfr:
            erfc = Erfcbafr(UGZY % enaqbz_fybtna())
        erghea erfc
